@@ -38,12 +38,10 @@ __version__ = _version.version
 
 if _TYPE_CHECKING:
     from argilla.client.api import (
-        active_client,
         copy,
         delete,
         delete_records,
         get_workspace,
-        init,
         list_datasets,
         list_workspaces,
         load,
@@ -65,6 +63,7 @@ if _TYPE_CHECKING:
         TokenAttributions,
         TokenClassificationRecord,
     )
+    from argilla.client.singleton import active_client, init
     from argilla.client.users import User
     from argilla.client.utils import server_info
     from argilla.client.workspaces import Workspace
@@ -78,18 +77,29 @@ if _TYPE_CHECKING:
     from argilla.feedback import (
         FeedbackDataset,
         FeedbackRecord,
+        FloatMetadataFilter,
+        FloatMetadataProperty,
+        IntegerMetadataFilter,
+        IntegerMetadataProperty,
         LabelQuestion,
         MultiLabelQuestion,
         RankingQuestion,
         RatingQuestion,
+        RecordSortField,
         ResponseSchema,
+        ResponseStatusFilter,
+        SortBy,
+        SortOrder,
+        SuggestionSchema,
+        TermsMetadataFilter,
+        TermsMetadataProperty,
         TextField,
         TextQuestion,
         ValueSchema,
+        VectorSettings,
     )
     from argilla.listeners import Metrics, RGListenerContext, Search, listener
     from argilla.monitoring.model_monitor import monitor
-    from argilla.server.server import app
 
 
 # TODO: remove me
@@ -106,21 +116,31 @@ _import_structure = {
         "RatingQuestion",
         "RankingQuestion",
         "ResponseSchema",
+        "ResponseStatusFilter",
         "TextField",
         "TextQuestion",
         "ValueSchema",
+        "IntegerMetadataProperty",
+        "FloatMetadataProperty",
+        "TermsMetadataProperty",
+        "TermsMetadataFilter",
+        "IntegerMetadataFilter",
+        "FloatMetadataFilter",
+        "SortBy",
+        "SortOrder",
+        "SuggestionSchema",
+        "RecordSortField",
+        "VectorSettings",
     ],
     "client.api": [
         "copy",
         "delete",
         "delete_records",
         "get_workspace",
-        "init",
         "load",
         "log",
         "log_async",
         "set_workspace",
-        "active_client",
         "list_datasets",
         "list_workspaces",
     ],
@@ -131,6 +151,10 @@ _import_structure = {
         "TokenClassificationRecord",
         "TokenAttributions",
     ],
+    "client.singleton": [
+        "init",
+        "active_client",
+    ],
     "client.datasets": [
         "DatasetForText2Text",
         "DatasetForTextClassification",
