@@ -18,8 +18,6 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Any, Dict, Iterable, List, Optional, Set, Tuple, Union
 
-from pydantic import BaseModel, Field
-
 from argilla.client.apis import AbstractApi, api_compatibility
 from argilla.client.sdk.commons.errors import (
     AlreadyExistsApiError,
@@ -29,6 +27,7 @@ from argilla.client.sdk.commons.errors import (
 )
 from argilla.client.sdk.datasets.api import get_dataset
 from argilla.client.sdk.datasets.models import TaskType
+from argilla.pydantic_v1 import BaseModel, Field
 
 
 @dataclass
@@ -57,19 +56,26 @@ class LabelsSchemaSettings(_AbstractSettings):
 
     """
 
-    label_schema: Set[str]
+    label_schema: List[str]
 
     def __post_init__(self):
         if not isinstance(self.label_schema, (set, list, tuple)):
             raise ValueError(
                 f"`label_schema` is of type={type(self.label_schema)}, but type=set is preferred, and also both type=list and type=tuple are allowed."
             )
-        self.label_schema = set([str(label) for label in self.label_schema])
+        self.label_schema = self._get_unique_labels()
+
+    def _get_unique_labels(self) -> List[str]:
+        unique_labels = []
+        for label in self.label_schema:
+            if label not in unique_labels:
+                unique_labels.append(label)
+        return unique_labels
 
     @classmethod
     def from_dict(cls, data: Dict[str, Any]) -> "LabelsSchemaSettings":
         label_schema = data.get("label_schema", {})
-        labels = {label["name"] for label in label_schema.get("labels", [])}
+        labels = [label["name"] for label in label_schema.get("labels", [])]
         return cls(label_schema=labels)
 
     @property
@@ -131,8 +137,8 @@ class Datasets(AbstractApi):
     class _SettingsApiModel(BaseModel):
         label_schema: Dict[str, Any]
 
-    def find_by_name(self, name: str) -> _DatasetApiModel:
-        dataset = get_dataset(self.http_client, name=name).parsed
+    def find_by_name(self, name: str, workspace: Optional[str] = None) -> _DatasetApiModel:
+        dataset = get_dataset(self.http_client, name=name, workspace=workspace).parsed
         return self._DatasetApiModel.parse_obj(dataset)
 
     def create(self, name: str, task: TaskType, workspace: str) -> _DatasetApiModel:
@@ -163,7 +169,7 @@ class Datasets(AbstractApi):
             )
             ds = self.create(name=name, task=task, workspace=workspace)
         except AlreadyExistsApiError:
-            ds = self.find_by_name(name)
+            ds = self.find_by_name(name, workspace=workspace)
         self._save_settings(dataset=ds, settings=settings)
 
     def scan(
@@ -322,7 +328,7 @@ class Datasets(AbstractApi):
         try:
             with api_compatibility(self, min_version="1.4"):
                 self.http_client.patch(
-                    f"{self._API_PREFIX}/{dataset.name}/{dataset.task.value}/settings",
+                    f"{self._API_PREFIX}/{dataset.name}/{dataset.task.value}/settings?workspace={dataset.workspace}",
                     json=settings_.dict(),
                 )
         except ApiCompatibilityError:
@@ -332,20 +338,24 @@ class Datasets(AbstractApi):
                     json=settings_.dict(),
                 )
 
-    def load_settings(self, name: str) -> Optional[Settings]:
+    def load_settings(self, name: str, workspace: Optional[str] = None) -> Optional[Settings]:
         """
         Load the dataset settings
 
         Args:
             name: The dataset name
+            workspace: The workspace name where the dataset belongs to
 
         Returns:
             Settings defined for the dataset
         """
-        dataset = self.find_by_name(name)
+        dataset = self.find_by_name(name, workspace=workspace)
         try:
             with api_compatibility(self, min_version="1.0"):
-                response = self.http_client.get(f"{self._API_PREFIX}/{dataset.name}/{dataset.task.value}/settings")
+                params = {"workspace": dataset.workspace} if dataset.workspace else {}
+                response = self.http_client.get(
+                    f"{self._API_PREFIX}/{dataset.name}/{dataset.task.value}/settings", params=params
+                )
                 return __TASK_TO_SETTINGS__.get(dataset.task).from_dict(response)
         except NotFoundApiError:
             return None
