@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 import warnings
-from typing import Any, Dict, List, Literal, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 from uuid import UUID
 
 import httpx
@@ -23,16 +23,24 @@ from argilla.client.sdk.commons.models import ErrorMessage, HTTPValidationError,
 from argilla.client.sdk.v1.datasets.models import (
     FeedbackDatasetModel,
     FeedbackFieldModel,
+    FeedbackListVectorSettingsModel,
+    FeedbackMetadataPropertyModel,
     FeedbackMetricsModel,
     FeedbackQuestionModel,
     FeedbackRecordsModel,
+    FeedbackRecordsSearchModel,
+    FeedbackRecordsSearchVectorQuery,
     FeedbackResponseStatusFilter,
-    FeedbackSuggestionModel,
+    FeedbackVectorSettingsModel,
 )
 
 
 def create_dataset(
-    client: httpx.Client, name: str, workspace_id: UUID, guidelines: Optional[str] = None
+    client: httpx.Client,
+    name: str,
+    workspace_id: Union[str, UUID],
+    guidelines: Optional[str] = None,
+    allow_extra_metadata: bool = True,
 ) -> Response[Union[FeedbackDatasetModel, ErrorMessage, HTTPValidationError]]:
     """Sends a POST request to `/api/v1/datasets` endpoint to create a new `FeedbackDataset`.
 
@@ -41,6 +49,7 @@ def create_dataset(
         name: the name of the dataset to be created.
         workspace_id: the id of the workspace where the dataset will be created.
         guidelines: the guidelines of the dataset to be created. Defaults to `None`.
+        allow_extra_metadata: whether to allow extra metadata not defined as a metadata property. Defaults to `True`.
 
     Returns:
         A `Response` object containing a `parsed` attribute with the parsed response if the
@@ -48,7 +57,7 @@ def create_dataset(
     """
     url = "/api/v1/datasets"
 
-    body = {"name": name, "workspace_id": str(workspace_id)}
+    body = {"name": name, "workspace_id": str(workspace_id), "allow_extra_metadata": allow_extra_metadata}
     if guidelines is not None:
         body.update({"guidelines": guidelines})
 
@@ -165,9 +174,12 @@ def list_datasets(
 def get_records(
     client: httpx.Client,
     id: UUID,
+    include: Union[None, List[str]] = None,
     offset: int = 0,
     limit: int = 50,
     response_status: Optional[List[FeedbackResponseStatusFilter]] = None,
+    metadata_filters: Optional[List[str]] = None,
+    sort_by: Optional[List[str]] = None,
 ) -> Response[Union[FeedbackRecordsModel, ErrorMessage, HTTPValidationError]]:
     """Sends a GET request to `/api/v1/datasets/{id}/records` endpoint to retrieve a
     list of `FeedbackTask` records.
@@ -175,22 +187,34 @@ def get_records(
     Args:
         client: the authenticated Argilla client to be used to send the request to the API.
         id: the id of the dataset to retrieve the records from.
+        include: the fields to be included in the response.
+             Can either be `responses`, `suggestions`, `vectors:all` or `vectors:vector_name_1,vector_name_2,...`
         offset: the offset to be used in the pagination. Defaults to 0.
         limit: the limit to be used in the pagination. Defaults to 50.
         response_status: the status of the responses to be retrieved. Can either be
             `draft`, `missing`, `discarded`, or `submitted`. Defaults to None.
+        metadata_filters: the metadata filters to be applied to the records. Defaults to None.
+        sort_by: the fields to be used to sort the records. Defaults to None.
 
     Returns:
         A `Response` object containing a `parsed` attribute with the parsed response if the
         request was successful, which is an instance of `FeedbackRecordsModel`.
     """
     url = f"/api/v1/datasets/{id}/records"
+    params = {"offset": offset, "limit": limit}
 
-    params = {"include": ["responses", "suggestions"], "offset": offset, "limit": limit}
+    if include:
+        params["include"] = include
 
-    if response_status is not None:
+    if response_status:
         params["response_status"] = response_status
 
+    if metadata_filters:
+        params["metadata"] = metadata_filters
+
+    if sort_by:
+        params["sort_by"] = sort_by
+
     response = client.get(url=url, params=params)
 
     if response.status_code == 200:
@@ -200,6 +224,59 @@ def get_records(
     return handle_response_error(response)
 
 
+def search_records(
+    client: httpx.Client,
+    id: UUID,
+    vector_query: FeedbackRecordsSearchVectorQuery,
+    include: Union[None, List[str]] = None,
+    response_status: Optional[List[FeedbackResponseStatusFilter]] = None,
+    metadata_filters: Optional[List[str]] = None,
+    limit: int = 50,
+) -> Response[Union[FeedbackRecordsSearchModel, ErrorMessage, HTTPValidationError]]:
+    """Sends a POST request to `/api/v1/datasets/{id}/records/search` endpoint to search for records inside an specific dataset.
+
+    Args:
+        client: the authenticated Argilla client to be used to send the request to the API.
+        id: the id of the dataset to add the records to.
+        include: the fields to be included in the response.
+        vector_query: the vector query to be used to search for records.
+        response_status: the status of the responses to be retrieved.
+            Can either be `draft`, `missing`, `discarded`, or `submitted`. Defaults to None.
+        metadata_filters: the metadata filters to be applied to the records. Defaults to None.
+        limit: an optional value to limit the number of returned records by the search.
+
+    Returns:
+        A `Response` object with the response itself, and/or the error codes if applicable.
+    """
+    url = f"/api/v1/datasets/{id}/records/search"
+
+    params = {"limit": limit}
+    if include:
+        params["include"] = include
+    if response_status:
+        params["response_status"] = response_status
+    if metadata_filters:
+        params["metadata"] = metadata_filters
+
+    vector_json = {"name": vector_query.name}
+    if vector_query.value:
+        vector_json["value"] = vector_query.value
+    if vector_query.record_id:
+        vector_json["record_id"] = str(vector_query.record_id)
+
+    json = {"query": {"vector": vector_json}}
+
+    response = client.post(url=url, params=params, json=json)
+
+    if response.status_code == 200:
+        response_obj = Response.from_httpx_response(response)
+        response_obj.parsed = FeedbackRecordsSearchModel(**response.json())
+
+        return response_obj
+
+    return handle_response_error(response)
+
+
 def add_records(
     client: httpx.Client, id: UUID, records: List[Dict[str, Any]]
 ) -> Response[Union[ErrorMessage, HTTPValidationError]]:
@@ -236,7 +313,8 @@ def add_records(
             if isinstance(response.get("user_id"), UUID):
                 response["user_id"] = str(response.get("user_id"))
             cleaned_responses.append(response)
-        record["responses"] = cleaned_responses
+        if len(cleaned_responses) > 0:
+            record["responses"] = cleaned_responses
 
         for suggestion in record.get("suggestions", []):
             if isinstance(suggestion.get("question_id"), UUID):
@@ -249,6 +327,42 @@ def add_records(
     return handle_response_error(response)
 
 
+def update_records(
+    client: httpx.Client, id: UUID, records: List[Dict[str, Any]]
+) -> Response[Union[ErrorMessage, HTTPValidationError]]:
+    """Sends a PATCH requests to `/api/v1/datasets/{id}/records` endpoint to update a
+    a list of `FeedbackTask` records from a `FeedbackDataset`.
+
+    Args:
+        client: the authenticated Argilla client to be used to send the request to the API.
+        id: the id of the dataset to update the records from.
+        records: the list of records to be updated.
+
+    Returns:
+        A `Response` object with the response itself, and/or the error codes if applicable.
+    """
+    url = f"/api/v1/datasets/{id}/records"
+
+    items = []
+    for record in records:
+        item = {"id": record["id"]}
+        if "metadata" in record:
+            item["metadata"] = record["metadata"]
+        if "suggestions" in record:
+            item["suggestions"] = record["suggestions"]
+        if "vectors" in record:
+            item["vectors"] = record["vectors"]
+
+        items.append(item)
+
+    response = client.patch(url=url, json={"items": items})
+
+    if response.status_code == 204:
+        return Response.from_httpx_response(response)
+
+    return handle_response_error(response)
+
+
 def delete_records(
     client: httpx.Client, id: UUID, record_ids: List[UUID]
 ) -> Response[Union[ErrorMessage, HTTPValidationError]]:
@@ -354,6 +468,8 @@ def add_question(
 
     Args:
         client: the authenticated Argilla client to be used to send the request to the API.
+        id: the id of the dataset to add the question to.
+        question: the question to be added to the dataset.
 
     Returns:
         A `Response` object containing a `parsed` attribute with the parsed response if the
@@ -370,53 +486,119 @@ def add_question(
     return handle_response_error(response)
 
 
-def set_suggestion(
-    client: httpx.Client,
-    record_id: UUID,
-    question_id: UUID,
-    value: Any,
-    type: Optional[Literal["model", "human"]] = None,
-    score: Optional[float] = None,
-    agent: Optional[str] = None,
-) -> Response[Union[FeedbackSuggestionModel, ErrorMessage, HTTPValidationError]]:
-    """Sends a PUT request to `/api/v1/records/{id}/suggestions` endpoint to add or update
-    a suggestion for a question in the `FeedbackDataset`.
+def get_metadata_properties(
+    client: httpx.Client, id: UUID
+) -> Response[Union[List[FeedbackMetadataPropertyModel], ErrorMessage, HTTPValidationError]]:
+    """Sends a GET request to `/api/v1/datasets/{id}/metadata-properties` endpoint to
+    retrieve a list of `FeedbackDataset` metadata properties.
 
     Args:
         client: the authenticated Argilla client to be used to send the request to the API.
-        record_id: the id of the record to add the suggestion to.
-        question_id: the id of the question to add the suggestion to.
-        value: the value of the suggestion.
-        type: the type of the suggestion. It can be either `model` or `human`. Defaults to None.
-        score: the score of the suggestion. Defaults to None.
-        agent: the agent used to obtain the suggestion. Defaults to None.
+        id: the id of the dataset to retrieve the metadata properties from.
 
     Returns:
         A `Response` object containing a `parsed` attribute with the parsed response if the
-        request was successful, which is a `FeedbackSuggestionModel`.
+        request was successful, which is a list of `FeedbackMetadataPropertyModel`.
     """
-    url = f"/api/v1/records/{record_id}/suggestions"
+    url = f"/api/v1/me/datasets/{id}/metadata-properties"
 
-    suggestion = {
-        "question_id": str(question_id),
-        "value": value,
-    }
-    if type is not None:
-        suggestion["type"] = type
-    if score is not None:
-        suggestion["score"] = score
-    if agent is not None:
-        suggestion["agent"] = agent
+    response = client.get(url=url)
 
-    response = client.put(url=url, json=suggestion)
-
-    if response.status_code in [200, 201]:
+    if response.status_code == 200:
         response_obj = Response.from_httpx_response(response)
-        response_obj.parsed = FeedbackSuggestionModel(**response.json())
+        response_obj.parsed = [FeedbackMetadataPropertyModel(**item) for item in response.json()["items"]]
         return response_obj
     return handle_response_error(response)
 
 
+def add_metadata_property(
+    client: httpx.Client, id: UUID, metadata_property: Dict[str, Any]
+) -> Response[Union[FeedbackMetadataPropertyModel, ErrorMessage, HTTPValidationError]]:
+    """Sends a POST request to `/api/v1/datasets/{id}/metadata-properties` endpoint to
+    add a metadata property to the `FeedbackDataset`.
+
+    Args:
+        client: the authenticated Argilla client to be used to send the request to the API.
+        id: the id of the dataset to add the metadata property to.
+        metadata_property: the metadata property to be added to the dataset.
+
+    Returns:
+        A `Response` object containing a `parsed` attribute with the parsed response if the
+        request was successful, which is a `FeedbackMetadataPropertyModel`.
+    """
+    url = f"/api/v1/datasets/{id}/metadata-properties"
+
+    response = client.post(url=url, json=metadata_property)
+
+    if response.status_code == 201:
+        response_obj = Response.from_httpx_response(response)
+        response_obj.parsed = FeedbackMetadataPropertyModel(**response.json())
+        return response_obj
+    return handle_response_error(response)
+
+
+def list_vectors_settings(
+    client: httpx.Client,
+    id: UUID,
+) -> Response[Union[FeedbackListVectorSettingsModel, ErrorMessage, HTTPValidationError]]:
+    """Sends a GET request to `/api/v1/datasets/{id}/vectors-settings` endpoint to
+    retrieve the vectors settings of a `FeedbackDataset`.
+
+    Args:
+        client: the authenticated Argilla client to be used to send the request to the API.
+        id: the id of the dataset to retrieve the vector settings from.
+
+    Returns:
+        A `Response` object containing a `parsed` attribute with the parsed response if the
+        request was successful, which is a `FeedbackListVectorSettingsModel`.
+    """
+    url = f"/api/v1/datasets/{id}/vectors-settings"
+
+    response = client.get(url=url)
+    if response.status_code == 200:
+        response_obj = Response.from_httpx_response(response)
+        response_obj.parsed = FeedbackListVectorSettingsModel(**response.json())
+        return response_obj
+
+    return handle_response_error(response)
+
+
+def add_vector_settings(
+    client: httpx.Client,
+    id: UUID,
+    name: str,
+    title: str,
+    dimensions: int,
+) -> Response[Union[FeedbackVectorSettingsModel, ErrorMessage, HTTPValidationError]]:
+    """Sends a POST request to `/api/v1/datasets/{id}/vectors-settings` endpoint to
+    add a vector settings to the `FeedbackDataset`.
+
+    Args:
+        client: the authenticated Argilla client to be used to send the request to the API.
+        id: the id of the dataset to add the vector settings to.
+
+    Returns:
+        A `Response` object containing a `parsed` attribute with the parsed response if
+        the request was successful, which is a `FeedbackVectorSettingsModel`.
+    """
+    url = f"/api/v1/datasets/{id}/vectors-settings"
+
+    body = {
+        "name": name,
+        "title": title,
+        "dimensions": dimensions,
+    }
+
+    response = client.post(url=url, json=body)
+    if response.status_code == 201:
+        response_obj = Response.from_httpx_response(response)
+        response_obj.parsed = FeedbackVectorSettingsModel(**response.json())
+        return response_obj
+
+    # TODO: better handle error for v1 API endpoints
+    return handle_response_error(response)
+
+
 def get_metrics(
     client: httpx.Client,
     id: UUID,
