@@ -14,20 +14,21 @@
 
 import logging
 import os
+import warnings
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, List, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
-from argilla.client.api import get_workspace, load
 from argilla.client.datasets import DatasetForText2Text, DatasetForTextClassification, DatasetForTokenClassification
 from argilla.client.models import Framework, Text2TextRecord, TextClassificationRecord, TokenClassificationRecord
+from argilla.client.singleton import active_client
 from argilla.datasets import TextClassificationSettings, TokenClassificationSettings, load_dataset_settings
 from argilla.utils.telemetry import get_telemetry_client
 
-os.environ["PYTORCH_ENABLE_MPS_FALLBACK"] = "1"
-
 if TYPE_CHECKING:
     import spacy
 
+    from argilla.client.feedback.integrations.huggingface import FrameworkCardData
+
 
 class ArgillaTrainer(object):
     _logger = logging.getLogger("ArgillaTrainer")
@@ -72,8 +73,10 @@ class ArgillaTrainer(object):
             framework_kwargs (dict): additional arguments for the framework.
             **load_kwargs: arguments for the rg.load() function.
         """
+        argilla = active_client()
+
         self._name = name
-        self._workspace = workspace or get_workspace()
+        self._workspace = workspace or argilla.get_workspace()
         self._multi_label = False
         self._split_applied = False
         self._train_size = train_size
@@ -83,7 +86,12 @@ class ArgillaTrainer(object):
         if train_size:
             self._split_applied = True
 
-        self.rg_dataset_snapshot = load(name=self._name, limit=1, workspace=workspace)
+        _pytorch_fallback_env = "PYTORCH_ENABLE_MPS_FALLBACK"
+        if _pytorch_fallback_env not in os.environ:
+            os.environ[_pytorch_fallback_env] = "1"
+            warnings.warn(f"{_pytorch_fallback_env} not set. Setting it to 1.", UserWarning, stacklevel=2)
+
+        self.rg_dataset_snapshot = argilla.load(name=self._name, limit=1, workspace=workspace)
         if not len(self.rg_dataset_snapshot) > 0:
             raise ValueError(f"Dataset {self._name} is empty")
 
@@ -97,7 +105,7 @@ class ArgillaTrainer(object):
         else:
             raise NotImplementedError(f"Dataset type {type(self.rg_dataset_snapshot)} is not supported.")
 
-        self.dataset_full = load(name=self._name, **load_kwargs)
+        self.dataset_full = argilla.load(name=self._name, **load_kwargs)
 
         # settings for the dataset
         self._settings = load_dataset_settings(name=self._name, workspace=workspace)
@@ -300,6 +308,36 @@ _________________________________________________________________
         """
         self._trainer.save(output_dir)
 
+    def get_model_kwargs(self):
+        """
+        Returns the model kwargs.
+        """
+        return self._trainer.get_model_kwargs()
+
+    def get_trainer_kwargs(self):
+        """
+        Returns the training kwargs.
+        """
+        return self._trainer.get_trainer_kwargs()
+
+    def get_trainer_model(self):
+        """
+        Returns the trainer model.
+        """
+        return self._trainer.get_model()
+
+    def get_trainer_tokenizer(self):
+        """
+        Returns the trainer tokenizer.
+        """
+        return self._trainer.get_tokenizer()
+
+    def get_trainer(self):
+        """
+        Returns the trainer trainer.
+        """
+        return self._trainer.get_trainer()
+
 
 class ArgillaTrainerSkeleton(ABC):
     def __init__(
@@ -331,6 +369,11 @@ class ArgillaTrainerSkeleton(ABC):
             self._id2label = None
         self._model = model
         self._seed = seed
+        self.model_kwargs = {}
+        self.trainer_kwargs = {}
+        self.trainer_model = None
+        self.trainer_tokenizer = None
+        self._trainer = None
 
     @abstractmethod
     def init_training_args(self):
@@ -367,3 +410,43 @@ class ArgillaTrainerSkeleton(ABC):
         """
         Saves the model to the specified path.
         """
+
+    def get_model_card_data(self, card_data_kwargs: Dict[str, Any]) -> "FrameworkCardData":
+        """
+        Generates a `FrameworkCardData` instance to generate a model card from.
+        """
+
+    def push_to_huggingface(self, repo_id: str, **kwargs) -> Optional[str]:
+        """
+        Uploads the model to [Huggingface Hub](https://huggingface.co/docs/hub/models-the-hub).
+        """
+
+    def get_model_kwargs(self):
+        """
+        Returns the model kwargs.
+        """
+        return self.model_kwargs
+
+    def get_trainer_kwargs(self):
+        """
+        Returns the training kwargs.
+        """
+        return self.trainer_kwargs
+
+    def get_model(self):
+        """
+        Returns the model.
+        """
+        return self._model
+
+    def get_tokenizer(self):
+        """
+        Returns the tokenizer.
+        """
+        return self.trainer_tokenizer
+
+    def get_trainer(self):
+        """
+        Returns the trainer.
+        """
+        return self._trainer
